pub enum ResolverError {
NoResolverForScheme {
scheme: IdScheme,
handle: String,
},
InvalidHandle(String),
Underlying {
handle: String,
source: Box<dyn Error + Send + Sync>,
},
CacheIntegrityViolation {
handle: String,
},
}Expand description
Resolver errors. Maps to runbooks under docs/runbooks/.
Variants
NoResolverForScheme
No resolver registered for the scheme of the input handle.
Fields
InvalidHandle(String)
AgentId failed to parse / validate.
Underlying
Underlying resolver returned an error.
Fields
CacheIntegrityViolation
Two consecutive lookups for the same handle returned contradicting fingerprints — possible cache poisoning.